TSUMUGI
Description: Tool for Identifying Gene Modules Based on KO Mouse Phenotype Similarity
Keywords: TSUMUGI, International Mouse Phenotyping Consortium (IMPC), Knockout mice, Gene module detection, Phenotype analysis

#

Trait-driven Surveillance for
Mutation-based Gene module Identification

Select a phenotype of interest
i
Searchable phenotype list here: Phenotype List

Enter a gene symbol
i
Searchable gene list here: Gene List

Enter gene symbols (one per line)

### Documentation & Contact

Documentation Contact

### Download Raw Data

Genewise Phenotype Annotations (JSONL.gz) Pairwise Similarity Annotations (JSONL.gz)